<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 * @return array An array of default values
 */

function edufication_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$edufication_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme'					=> 'default',
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'menu_style'					=> 'classic-menu',
		'nav_search_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'edufication-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'edufication-pro' ), '[the-year]', '[site-link]' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'edufication-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,
		'footer_social_visible'        	=> false,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'Banner,Services,About Us,Courses,Subscribe and CountDown,Events,Testimonial,Team,Call to Action,Blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'edufication-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// topbar
		'topbar_section_enable'			=> true,
		'topbar_social_enable'			=> false,
		'topbar_content_type'			=> 'category',
		'topbar_count'					=> 2,
		'topbar_email'					=> 'info@themepalace.com',
		'topbar_phone'					=> esc_html__( '+0 00 000000000', 'edufication-pro' ),
		'topbar_news_label'				=> esc_html__( 'News', 'edufication-pro' ),

		// banner
		'banner_section_enable'			=> true,
		'banner_content_type'			=> 'page',
		'banner_title'					=> esc_html__( 'Welcome to our edufication', 'edufication-pro' ),
		'banner_description'			=> esc_html__( 'We’re  here to help you for your education. Have fun & learn.', 'edufication-pro' ),
		'banner_btn_label'				=> esc_html__( 'Learn More', 'edufication-pro' ),
		'banner_add_btn_label'			=> esc_html__( 'Register Now', 'edufication-pro' ),
		'banner_image'					=> get_template_directory_uri() . '/assets/uploads/hero-banner.jpg',

		// service
		'service_section_enable'		=> true,
		'service_modern_enable'			=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 4,
		'service_column'				=> 2,
		'service_title'					=> esc_html__( 'We Provide The Best For You!', 'edufication-pro' ),
		'service_description'			=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis imperdiet nunc fringilla, placerat turpis eget, ultricies libero. Suspendisse rutrum sem tellus, ut porta neque eleifend sit amet.', 'edufication-pro' ),
		'service_btn_label'				=> esc_html__( 'View All Services', 'edufication-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'White high rise building by Michal Nowak', 'edufication-pro' ),
		'about_description'				=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit.', 'edufication-pro' ),
		'about_btn_title'				=> esc_html__( 'Know us more', 'edufication-pro' ),

		// course
		'course_section_enable'			=> true,
		'course_content_type'			=> 'category',
		'course_count'					=> 6,
		'course_column'					=> 3,
		'course_title'					=> esc_html__( 'Learn Our Most Valuable Courses Here', 'edufication-pro' ),
		'course_btn_label'				=> esc_html__( 'View All Courses', 'edufication-pro' ),

		// subscribe
		'subscribe_section_enable'		=> false,
		'subscribe_enable'				=> false,
		'count_down_enable'				=> false,
		'subscribe_section_title'		=> esc_html__( 'Our Next Course Starting', 'edufication-pro' ),
		'subscribe_section_sub_title'	=> esc_html__( 'Become a Member Today', 'edufication-pro' ),
		'subscription_title'			=> esc_html__( 'Subscribe our newsletter to get the latest news/events delivered right to your inbox.', 'edufication-pro' ),
		'subscribe_image'				=> get_template_directory_uri() . '/assets/uploads/subscribe-newsletter-bg.jpg',

		// event
		'event_section_enable'			=> true,
		'event_content_type'			=> 'category',
		'event_count'					=> 3,
		'event_title'					=> esc_html__( 'Our Educational Upcoming News/Events', 'edufication-pro' ),
		'event_btn_label'				=> esc_html__( 'View All Upcoming Events', 'edufication-pro' ),
		'event_read_more_label'			=> esc_html__( 'View Our Event', 'edufication-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_content_type'		=> 'category',
		'testimonial_column'			=> 3,
		'testimonial_count'				=> 3,
		'testimonial_title'				=> esc_html__( 'What Happy People Said About Edufication', 'edufication-pro' ),

		// team
		'team_section_enable'			=> true,
		'team_content_type'				=> 'category',
		'team_column'					=> 4,
		'team_count'					=> 4,
		'team_title'					=> esc_html__( 'Our Awesome & Creative Team Members', 'edufication-pro' ),

		// call to action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'custom',
		'cta_image'						=> get_template_directory_uri() . '/assets/uploads/call-to-action.jpg',
		'cta_title'						=> esc_html__( 'Learning Is Fun With Us', 'edufication-pro' ),
		'cta_description'				=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Duis imperdiet nunc fringilla, placerat turpis eget, ultricies libero. Suspendisse rutrum sem tellus, ut porta neque eleifend sit amet.', 'edufication-pro' ),
		'cta_btn_title'					=> esc_html__( 'Learn More', 'edufication-pro' ),
		'cta_add_btn_title'				=> esc_html__( 'Join Us Now', 'edufication-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'category',
		'blog_count'					=> 3,
		'blog_column'					=> 'col-3',
		'blog_title'					=> esc_html__( 'Our Thoughts, Comments And Posts', 'edufication-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Blog Posts', 'edufication-pro' ),
		'blog_btn_url'					=> '#',

	);

	$output = apply_filters( 'edufication_pro_default_theme_options', $edufication_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}