<?php
/**
 * Course Section options
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */

// Add Course section
$wp_customize->add_section( 'edufication_pro_course_section', array(
	'title'             => esc_html__( 'Courses','edufication-pro' ),
	'description'       => esc_html__( 'Courses Section options.', 'edufication-pro' ),
	'panel'             => 'edufication_pro_front_page_panel',
) );

// Course content enable control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[course_section_enable]', array(
	'default'			=> 	$options['course_section_enable'],
	'sanitize_callback' => 'edufication_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Edufication_Pro_Switch_Control( $wp_customize, 'edufication_pro_theme_options[course_section_enable]', array(
	'label'             => esc_html__( 'Course Section Enable', 'edufication-pro' ),
	'section'           => 'edufication_pro_course_section',
	'on_off_label' 		=> edufication_pro_switch_options(),
) ) );

// Courses Layout control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[course_column]', array(
	'default'          	=> $options['course_column'],
	'sanitize_callback' => 'edufication_pro_sanitize_select',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[course_column]', array(
	'label'             => esc_html__( 'Column Layout', 'edufication-pro' ),
	'section'           => 'edufication_pro_course_section',
	'type'				=> 'select',
	'active_callback' 	=> 'edufication_pro_is_course_section_enable',
	'choices'			=> array( 
		2 		=> esc_html__( 'Two Column', 'edufication-pro' ),
		3 		=> esc_html__( 'Three Column', 'edufication-pro' ),
	),
) );

// course title setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[course_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[course_title]', array(
	'label'           	=> esc_html__( 'Title', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_course_section',
	'active_callback' 	=> 'edufication_pro_is_course_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[course_title]', array(
		'selector'            => '#courses-section .section-header h2.section-title',
		'settings'            => 'edufication_pro_theme_options[course_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_course_title_partial',
    ) );
}

// course btn label setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[course_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['course_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[course_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_course_section',
	'active_callback' 	=> 'edufication_pro_is_course_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[course_btn_label]', array(
		'selector'            => '#courses-section .more-link a',
		'settings'            => 'edufication_pro_theme_options[course_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_course_btn_label_partial',
    ) );
}

// course btn url setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[course_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'			=> '#',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[course_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_course_section',
	'active_callback' 	=> 'edufication_pro_is_course_section_enable',
	'type'				=> 'url',
) );

// course number control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[course_count]', array(
	'default'          	=> $options['course_count'],
	'sanitize_callback' => 'edufication_pro_sanitize_number_range',
	'validate_callback' => 'edufication_pro_validate_course_count',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[course_count]', array(
	'label'             => esc_html__( 'Number of Courses', 'edufication-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'edufication-pro' ),
	'section'           => 'edufication_pro_course_section',
	'active_callback'   => 'edufication_pro_is_course_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Course content type control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[course_content_type]', array(
	'default'          	=> $options['course_content_type'],
	'sanitize_callback' => 'edufication_pro_sanitize_select',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[course_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'edufication-pro' ),
	'section'           => 'edufication_pro_course_section',
	'type'				=> 'select',
	'active_callback' 	=> 'edufication_pro_is_course_section_enable',
	'choices'			=> edufication_pro_course_section_options(),
) );

for ( $i = 1; $i <= $options['course_count']; $i++ ) :

	// course pages drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[course_content_page_' . $i . ']', array(
		'sanitize_callback' => 'edufication_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[course_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_course_section',
		'choices'			=> edufication_pro_page_choices(),
		'active_callback'	=> 'edufication_pro_is_course_section_content_page_enable',
	) ) );

	// course posts drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[course_content_post_' . $i . ']', array(
		'sanitize_callback' => 'edufication_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[course_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Course %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_course_section',
		'choices'			=> edufication_pro_post_choices(),
		'active_callback'	=> 'edufication_pro_is_course_section_content_post_enable',
	) ) );

	// course posts drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[course_content_course_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[course_content_course_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Course %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_course_section',
		'choices'			=> edufication_pro_custom_post_choices( 'tp-course' ),
		'active_callback'	=> 'edufication_pro_is_course_section_content_course_enable',
	) ) );
	
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'edufication_pro_theme_options[course_content_category]', array(
	'sanitize_callback' => 'edufication_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Edufication_Pro_Dropdown_Taxonomies_Control( $wp_customize,'edufication_pro_theme_options[course_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'edufication-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'edufication-pro' ),
	'section'           => 'edufication_pro_course_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'edufication_pro_is_course_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'edufication_pro_theme_options[course_content_course_cat]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Edufication_Pro_Dropdown_Taxonomies_Control( $wp_customize,'edufication_pro_theme_options[course_content_course_cat]', array(
	'label'             => esc_html__( 'Select Course Category', 'edufication-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of courses will be shown from selected course category', 'edufication-pro' ),
	'taxonomy'			=> 'tp-course-category',
	'section'           => 'edufication_pro_course_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'edufication_pro_is_course_section_content_course_category_enable'
) ) );
