<?php
/**
 * Subscribe Section options
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */

// Add Subscribe section
$wp_customize->add_section( 'edufication_pro_subscribe_section', array(
	'title'             => esc_html__( 'Subscribe & Count Down','edufication-pro' ),
	'description'       => esc_html__( 'Subscribe Section options.', 'edufication-pro' ),
	'panel'             => 'edufication_pro_front_page_panel',
) );

// Subscribe content enable control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[subscribe_section_enable]', array(
	'default'			=> 	$options['subscribe_section_enable'],
	'sanitize_callback' => 'edufication_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Edufication_Pro_Switch_Control( $wp_customize, 'edufication_pro_theme_options[subscribe_section_enable]', array(
	'label'             => esc_html__( 'Subscribe & Count Down Enable', 'edufication-pro' ),
	'section'           => 'edufication_pro_subscribe_section',
	'on_off_label' 		=> edufication_pro_switch_options(),
) ) );

// subscribe sub_title setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[subscribe_section_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscribe_section_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[subscribe_section_sub_title]', array(
	'label'           	=> esc_html__( 'Section Sub Title ', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_subscribe_section',
	'active_callback' 	=> 'edufication_pro_is_subscribe_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[subscribe_section_sub_title]', array(
		'selector'            => '#subscribe-newsletter .wrapper .section-header .section-subtitle',
		'settings'            => 'edufication_pro_theme_options[subscribe_section_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_subscribe_section_sub_title_partial',
    ) );
}

// subscribe title setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[subscribe_section_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscribe_section_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[subscribe_section_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_subscribe_section',
	'active_callback' 	=> 'edufication_pro_is_subscribe_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[subscribe_section_title]', array(
		'selector'            => '#subscribe-newsletter .wrapper .section-header .section-title',
		'settings'            => 'edufication_pro_theme_options[subscribe_section_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_subscribe_section_title_partial',
    ) );
}

// subscribe image setting and control.
$wp_customize->add_setting( 'edufication_pro_theme_options[subscribe_image]', array(
	'default'			=> $options['subscribe_image'],
	'sanitize_callback' => 'edufication_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'edufication_pro_theme_options[subscribe_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'edufication-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'edufication-pro' ), 1950, 550 ),
		'section'     		=> 'edufication_pro_subscribe_section',
		'active_callback' 	=> 'edufication_pro_is_subscribe_section_enable',
) ) );

// Subscribe content enable control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[subscribe_enable]', array(
	'default'			=> 	$options['subscribe_enable'],
	'sanitize_callback' => 'edufication_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Edufication_Pro_Switch_Control( $wp_customize, 'edufication_pro_theme_options[subscribe_enable]', array(
	'label'             => esc_html__( 'Subscribe Enable', 'edufication-pro' ),
	'description'       => esc_html__( 'Install Jetpack and Enable Subscription Module to activate Subsription form.', 'edufication-pro' ),
	'section'           => 'edufication_pro_subscribe_section',
	'active_callback' 	=> 'edufication_pro_is_subscribe_section_enable',
	'on_off_label' 		=> edufication_pro_switch_options(),
) ) );

// subscribe title setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['subscription_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Subscription Title', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_subscribe_section',
	'active_callback' 	=> 'edufication_pro_is_subscribe_section_content_subscribe_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[subscription_title]', array(
		'selector'            => '#subscribe-newsletter .wrapper .jetpack_subscription_widget h2.widgettitle',
		'settings'            => 'edufication_pro_theme_options[subscription_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_subscription_title_partial',
    ) );
}

// Subscribe content enable control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[count_down_enable]', array(
	'default'			=> 	$options['count_down_enable'],
	'sanitize_callback' => 'edufication_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Edufication_Pro_Switch_Control( $wp_customize, 'edufication_pro_theme_options[count_down_enable]', array(
	'label'             => esc_html__( 'Count Down Enable', 'edufication-pro' ),
	'section'           => 'edufication_pro_subscribe_section',
	'active_callback' 	=> 'edufication_pro_is_subscribe_section_enable',
	'on_off_label' 		=> edufication_pro_switch_options(),
) ) );

// subscribe title setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[count_down_date]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[count_down_date]', array(
	'label'           	=> esc_html__( 'Select Release Date', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_subscribe_section',
	'active_callback' 	=> 'edufication_pro_is_subscribe_section_content_count_down_enable',
	'type'				=> 'date',
) );