<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'edufication_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','edufication-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'edufication-pro' ),
	'panel'             => 'edufication_pro_front_page_panel',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'edufication_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Edufication_Pro_Switch_Control( $wp_customize, 'edufication_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'edufication-pro' ),
	'section'           => 'edufication_pro_testimonial_section',
	'on_off_label' 		=> edufication_pro_switch_options(),
) ) );

// Testimonial Layout control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[testimonial_column]', array(
	'default'          	=> $options['testimonial_column'],
	'sanitize_callback' => 'edufication_pro_sanitize_select',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[testimonial_column]', array(
	'label'             => esc_html__( 'Column Layout', 'edufication-pro' ),
	'section'           => 'edufication_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'edufication_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		1 		=> esc_html__( 'One Column', 'edufication-pro' ),
		2 		=> esc_html__( 'Two Column', 'edufication-pro' ),
		3 		=> esc_html__( 'Three Column', 'edufication-pro' ),
	),
) );

// testimonial title setting and control
$wp_customize->add_setting( 'edufication_pro_theme_options[testimonial_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['testimonial_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[testimonial_title]', array(
	'label'           	=> esc_html__( 'Title', 'edufication-pro' ),
	'section'        	=> 'edufication_pro_testimonial_section',
	'active_callback' 	=> 'edufication_pro_is_testimonial_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'edufication_pro_theme_options[testimonial_title]', array(
		'selector'            => '#clients-section .section-header h2.section-title',
		'settings'            => 'edufication_pro_theme_options[testimonial_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'edufication_pro_testimonial_title_partial',
    ) );
}

// testimonial number control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'edufication_pro_sanitize_number_range',
	'validate_callback' => 'edufication_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonial', 'edufication-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'edufication-pro' ),
	'section'           => 'edufication_pro_testimonial_section',
	'active_callback'   => 'edufication_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'edufication_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'edufication_pro_sanitize_select',
) );

$wp_customize->add_control( 'edufication_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'edufication-pro' ),
	'section'           => 'edufication_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'edufication_pro_is_testimonial_section_enable',
	'choices'			=> edufication_pro_testimonial_section_options(),
) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :

	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'edufication_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_testimonial_section',
		'choices'			=> edufication_pro_page_choices(),
		'active_callback'	=> 'edufication_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'edufication_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Testimonial %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_testimonial_section',
		'choices'			=> edufication_pro_post_choices(),
		'active_callback'	=> 'edufication_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'edufication_pro_theme_options[testimonial_content_testimonial_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new Edufication_Pro_Dropdown_Chooser( $wp_customize, 'edufication_pro_theme_options[testimonial_content_testimonial_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Testimonial %d', 'edufication-pro' ), $i ),
		'section'           => 'edufication_pro_testimonial_section',
		'choices'			=> edufication_pro_custom_post_choices( 'tp-testimonial' ),
		'active_callback'	=> 'edufication_pro_is_testimonial_section_content_testimonial_enable',
	) ) );
	
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'edufication_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'edufication_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Edufication_Pro_Dropdown_Taxonomies_Control( $wp_customize,'edufication_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'edufication-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'edufication-pro' ),
	'section'           => 'edufication_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'edufication_pro_is_testimonial_section_content_category_enable'
) ) );
