<?php
/**
 * Client section
 *
 * This is the template for the content of topbar section
 *
 * @package Theme Palace
 * @subpackage Edufication Pro
 * @since Edufication Pro 1.0.0
 */
if ( ! function_exists( 'edufication_pro_add_topbar_section' ) ) :
    /**
    * Add topbar section
    *
    *@since Edufication Pro 1.0.0
    */
    function edufication_pro_add_topbar_section() {
        // Get topbar section details
        $section_details = array();
        $section_details = apply_filters( 'edufication_pro_filter_topbar_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render topbar section now.
        edufication_pro_render_topbar_section( $section_details );
    }
endif;
add_action( 'edufication_pro_topbar_news_action', 'edufication_pro_add_topbar_section', 10 );

if ( ! function_exists( 'edufication_pro_get_topbar_section_details' ) ) :
    /**
    * topbar section details.
    *
    * @since Edufication Pro 1.0.0
    * @param array $input topbar section details.
    */
    function edufication_pro_get_topbar_section_details( $input ) {
        $options = edufication_pro_get_theme_options();

        // Content type.
        $topbar_content_type  = $options['topbar_content_type'];
        $topbar_count = ! empty( $options['topbar_count'] ) ? $options['topbar_count'] : 2;
        
        $content = array();
        switch ( $topbar_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $topbar_count; $i++ ) {
                    if ( ! empty( $options['topbar_content_page_' . $i] ) )
                        $page_ids[] = $options['topbar_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $topbar_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $topbar_count; $i++ ) {
                    if ( ! empty( $options['topbar_content_post_' . $i] ) )
                        $post_ids[] = $options['topbar_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $topbar_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['topbar_content_category'] ) ? $options['topbar_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $topbar_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        $i = 0;
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();

                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// topbar section content details.
add_filter( 'edufication_pro_filter_topbar_section_details', 'edufication_pro_get_topbar_section_details' );


if ( ! function_exists( 'edufication_pro_render_topbar_section' ) ) :
  /**
   * Start topbar section
   *
   * @return string topbar content
   * @since Edufication Pro 1.0.0
   *
   */
   function edufication_pro_render_topbar_section( $content_details = array() ) {
        $options = edufication_pro_get_theme_options();
        $label = ! empty( $options['topbar_news_label'] ) ? $options['topbar_news_label'] : esc_html__( 'News', 'edufication-pro' );
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div class="latest-news">
            <span class="latest-news-header">
                <?php echo edufication_pro_get_svg( array( 'icon' => 'news' ) ); ?>
                <span><?php echo esc_html( $label ); ?></span>
            </span>

            <div class="latest-news-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": false, "arrows":false, "autoplay": true, "draggable": true, "vertical": true, "fade": false }'>
                <?php foreach( $content_details as $content ) : ?>
                    <div class="slick-item">
                        <a href="<?php echo esc_url( $content['url'] ); ?>"><p><?php echo esc_html( $content['title'] ); ?></p></a>
                    </div><!-- .slick-item -->
                <?php endforeach; ?>
            </div><!-- .latest-news-slider-->
        </div><!-- .latest-news -->

    <?php }
endif;